@@ -134,6 +134,11 @@ class PyXploraApi(PyXplora):
             "watch_charging": isCharging,
             "locateType": locateType,
             "lastTrackTime": watch_location.get("tm", datetime.now().strftime("%Y-%m-%d %H:%M:%S")),
+            "lat": watch_location.get("lat", None),
+            "lng": watch_location.get("lng", None),
+            "rad": watch_location.get("rad", -1),
+            "step": watch_location.get("step", 0),
+            "distance": watch_location.get("distance", -1),
             "isInSafeZone": isInSafeZone,
             "safeZoneLabel": safeZoneLabel,
             "getWatchSafeZones": watch_safe_zones,
